
/*
 * main.cpp - main line/os entry point
 * $Id: main.cpp,v 1.1.1.1 1999/04/27 00:28:27 ademko Exp $
 *
 * Copyright (C) 1999 Alex Demko <ademko@mbnet.mb.ca>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include <os.h>
#include <def.h>
#include <wmain.h>

// argument handler call back
static void cb_arg_handle(poptContext con, enum poptCallbackReason reason,
    const struct poptOption * opt, const char * arg, void * data);

// option table
static const struct poptOption cmd_options[] = {
    {NULL,0,POPT_ARG_CALLBACK|POPT_CBFLAG_POST,cb_arg_handle,0,NULL,NULL },
    {"level",'l',POPT_ARG_STRING,NULL,
        -1,"Specify level to load","level_file"},
    {"tiles",'t',POPT_ARG_STRING,NULL,
        -2,"Specify tiles to load","tile_file"},
    {NULL,0,POPT_ARG_NONE,NULL,0,NULL,NULL},
};

// main line/os entry point
int main(int argc, char *argv[]) {

    // init string settings
    stage_filename = NULL;
    tiles_filename = NULL;
    // start up gnome/parse options
    gnome_init_with_popt_table("gdstar", GDSTAR_VERSION, argc, argv,
        cmd_options, 2, NULL);
    // set defaults if none were set
    if (!stage_filename)
        stage_filename = g_strdup(DEFAULT_LEVEL);
    if (!tiles_filename)
        tiles_filename = g_strdup(DEFAULT_TILES);

    // run the app
    wmain_new();
    gtk_main();
    wmain_delete();

    // clean up
    g_free(stage_filename);
    g_free(tiles_filename);

    // exit
    return EXIT_SUCCESS;
}

// argument handler call back
static void cb_arg_handle(poptContext con, enum poptCallbackReason reason,
    const struct poptOption * opt, const char * arg, void * data) {

    // check the reason
    if (reason != POPT_CALLBACK_REASON_OPTION)
        return;

    // check which option we're setting
    switch (opt->val) {
        case -1:
            // set a level name
            if (stage_filename)
                g_free(stage_filename);
            stage_filename = g_strdup(arg);
            break;
        case -2:
            // set a tiles graphic file name
            if (tiles_filename)
                g_free(tiles_filename);
            tiles_filename = g_strdup(arg);
            break;
    }
}

