
/*
 * room.cpp - a room or level class
 * $Id: room.cpp,v 1.1.1.1 1999/04/27 00:28:28 ademko Exp $
 *
 * Copyright (C) 1999 Alex Demko <ademko@mbnet.mb.ca>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include <room.h>
#include <os.h>

// default constructor
room::room(void) {
    cell = NULL;
    load_default();
}

// load a particular filename
room::room(const char *filename) {
    cell = NULL;
    load_file(filename);
}

// destructor
room::~room() {
    delete cell;
}

// sets up a default, simple level
void room::load_default(void) {
    int x, y;

    // set up the screen
    w = 16;
    h = 9;

    delete cell;
    cell = new state[w*h];

    foodleft = 0;
    for (y=0; y<h; y++)
        for (x=0; x<w; x++)
            cell[x + y*w] = s_none; //dont wanna use set() here

    // make the walls
    for (x=0; x<w; x++) {
        set(x, 0, s_wall);
        set(x, h-1, s_wall);
    }
    for (y=0; y<h; y++) {
        set(0, y, s_wall);
        set(w-1, y, s_wall);
    }

    // insert the player and buddy
    set(1, 1, s_player);
    set(w - 2, h - 2, s_buddy);
}

// load a particular file
bool room::load_file(const char *filename) {
    ifstream inf;
    string id;
    int x, y;

    // try to open the given file
    inf.open(filename);
    if (!inf)
        return false;   // cant open file

    // read header
    inf >> id >> x >> y;

    // verify header
    if (id != string("DSTARSTAGE"))
        return false;

    // read dimensions
    inf >> w >> h;

    // set up the area
    delete cell;
    cell = new state[w*h];

    foodleft = 0;
    for (y=0; y<h; y++)
        for (x=0; x<w; x++)
            cell[x + y*w] = s_none; //dont wanna use set() here*/

    // iterate through all the objects in the file, quiting on -1
    while ( (inf >> x), x > -1 ) {
        inf >> y >> id;
        // determine the type of object and insert it into the room
        if (id == string("wall"))
            set(x, y, s_wall);
        else if (id == string("food"))
            set(x, y, s_food);
        else if (id == string("player"))
            set(x, y, s_player);
        else if (id == string("buddy"))
            set(x, y, s_buddy);
    }

    // return ok
    return true;
}

// return board width
int room::get_w(void) {
    return w;
}

// return board height
int room::get_h(void) {
    return h;
}

// return player's x coord
int room::get_player_x(void) {
    return playerx;
}

// return player's y coord
int room::get_player_y(void) {
    return playery;
}

// return buddy's x coord
int room::get_buddy_x(void) {
    return buddyx;
}

// return buddy's y coord
int room::get_buddy_y(void) {
    return buddyy;
}

// return food count
int room::get_food_left(void) {
    return foodleft;
}

// return the state of a particular cell
room::state room::get(int _x, int _y) {
    return cell[_y * w + _x];
}

// set the state of a cell
room::state room::set(int _x, int _y, room::state new_state) {
    state old;
    
    // save old cell
    old = cell[_y * w + _x];
    cell[_y * w + _x] = new_state;

    // check if we need to update our player or buddy coords
    if (new_state == s_player) {
        playerx = _x;
        playery = _y;
    } else if (new_state == s_buddy) {
        buddyx = _x;
        buddyy = _y;
    }

    // check if we need to adjust our food count
    if ( (old == s_food) && (new_state != s_food) )
        foodleft--;
    else if ( (old != s_food) && (new_state == s_food) )
        foodleft++;

    return old;
}


