
/*
 * room.h - a room or level class
 * $Id: room.h,v 1.1.1.1 1999/04/27 00:28:28 ademko Exp $
 *
 * Copyright (C) 1999 Alex Demko <ademko@mbnet.mb.ca>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifndef __INCLUDED_ROOM_H__236423964
#define __INCLUDED_ROOM_H__236423964

// the room class
class room {
    
    public:

        // default constructor
        room(void);
        // load a particular filename
        room(const char *filename);
        // destructor
        ~room();

    public:

        // sets up a default, simple level
        void load_default(void);
        // load a particular file
        bool load_file(const char *filename);   // true if all ok

        // return board width
        int get_w(void);
        // return board height
        int get_h(void);

        // return player's x coord
        int get_player_x(void);
        // return player's y coord
        int get_player_y(void);
        // return buddy's x coord
        int get_buddy_x(void);
        // return buddy's y coord
        int get_buddy_y(void);
        // return food count
        int get_food_left(void);

        // the various states a room cell can have
        typedef enum {
            s_none,     // nothing here
            s_wall,     // a wall
            s_food,     // food
            s_player,   // player (collector)
            s_buddy,    // buddy (obstacle)
            s_MAX,      // used for looping
        } state;

        // return the state of a particular cell
        state get(int _x, int _y);
        // set the state of a cell
        state set(int _x, int _y, state new_state);

    private:

        int w, h,               // board dimensions
            playerx, playery,   // player's coords
            buddyx, buddyy,     // buddy's coords
            foodleft;           // food left
        state *cell;            // the map cells (2D array)
};

#endif

